@@ -3,15 +3,6 @@
 #include "eggtoolbar.h"
 #include "eggintl.h"
 
-
-/* some code for making arbitrary GtkButtons that act like toolbar
- * buttons */
-static GtkWidget *tool_button_new       (GType        button_type,
-					 const gchar *text,
-					 GtkWidget   *icon);
-static GtkWidget *tool_button_get_label (GtkWidget   *button);
-static GtkWidget *tool_button_get_icon  (GtkWidget   *button);
-
 enum {
   ACTIVATE,
   LAST_SIGNAL
@@ -26,6 +17,7 @@ enum {
   PROP_STOCK_ID,
   PROP_SENSITIVE,
   PROP_VISIBLE,
+  PROP_IMPORTANT
 };
 
 static void egg_action_init       (EggAction *action);
@@ -151,6 +143,14 @@ egg_action_class_init (EggActionClass *class)
 							 TRUE,
 							 G_PARAM_READWRITE));
 
+  g_object_class_install_property (object_class,
+				   PROP_IMPORTANT,
+				   g_param_spec_boolean ("important",
+							 _("Important"),
+							 _("Important."),
+							 FALSE,
+							 G_PARAM_READWRITE));
+
   g_object_class_install_property (object_class,
 				   PROP_VISIBLE,
 				   g_param_spec_boolean ("visible",
@@ -182,6 +182,7 @@ egg_action_init (EggAction *action)
 
   action->sensitive = TRUE;
   action->visible = TRUE;
+  action->important = FALSE;
 
   action->label_set = FALSE;
   action->short_label_set = FALSE;
@@ -296,6 +297,10 @@ egg_action_set_property (GObject         *object,
     case PROP_VISIBLE:
       action->visible = g_value_get_boolean (value);
       break;
+    case PROP_IMPORTANT:
+      action->important = g_value_get_boolean (value);
+      g_object_notify(object, "important");
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -335,6 +340,9 @@ egg_action_get_property (GObject    *object,
     case PROP_VISIBLE:
       g_value_set_boolean (value, action->visible);
       break;
+    case PROP_IMPORTANT:
+      g_value_set_boolean (value, action->important);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -383,6 +391,12 @@ egg_action_sync_property (EggAction *action, GParamSpec *pspec,
   g_value_unset (&value);
 }
 
+static void
+egg_action_sync_important (EggAction *action, GParamSpec *pspec, GtkWidget *proxy)
+{
+	egg_tool_item_set_is_important (EGG_TOOL_ITEM (proxy), action->important);
+}
+
 static void
 egg_action_sync_tooltip (EggAction *action, GParamSpec *pspec, GtkWidget *proxy)
 {
@@ -537,8 +551,6 @@ connect_proxy (EggAction *action, GtkWidget *proxy)
     }
   else if (EGG_IS_TOOL_BUTTON (proxy))
     {
-      GtkWidget *label;
-      GtkWidget *icon;
       /* toolbar button specific synchronisers ... */
 
       /* synchronise the label */
@@ -550,6 +562,10 @@ connect_proxy (EggAction *action, GtkWidget *proxy)
 			       G_CALLBACK (egg_action_sync_short_label),
 			       proxy, 0);
 
+      egg_action_sync_important (action, NULL, proxy);
+      g_signal_connect_object (action, "notify::important",
+			       G_CALLBACK (egg_action_sync_important), proxy, 0);
+
       g_object_set (G_OBJECT (proxy), "stock_id", action->stock_id, NULL);
       g_signal_connect_object (action, "notify::stock_id",
 			G_CALLBACK (egg_action_sync_property), proxy, 0);
@@ -742,8 +758,6 @@ void
 egg_action_disconnect_proxy (EggAction *action,
 			     GtkWidget *proxy)
 {
-  EggAction *prev_action;
-
   g_return_if_fail (EGG_IS_ACTION (action));
   g_return_if_fail (GTK_IS_WIDGET (proxy));
 
@@ -806,202 +820,3 @@ egg_action_set_accel_path (EggAction *action, const gchar *accel_path)
 {
   action->accel_quark = g_quark_from_string(accel_path);
 }
-
-/* ---- code to create sort-of-toolbar-buttons ---- */
-
-static GtkWidget *
-tool_button_get_label (GtkWidget *button)
-{
-  g_return_val_if_fail (GTK_IS_BUTTON (button), NULL);
-
-  return g_object_get_data (G_OBJECT (button), "tool-button-label");
-}
-
-static GtkWidget *
-tool_button_get_icon (GtkWidget *button)
-{
-  g_return_val_if_fail (GTK_IS_BUTTON (button), NULL);
-
-  return g_object_get_data (G_OBJECT (button), "tool-button-icon");
-}
-
-static void
-tool_button_parent_set (GtkWidget *button, GtkWidget *old_parent)
-{
-  GtkWidget *box;
-  GtkWidget *label;
-  GtkWidget *icon;
-
-  box   = g_object_get_data (G_OBJECT (button), "tool-button-box");
-  label = g_object_get_data (G_OBJECT (button), "tool-button-label");
-  icon  = g_object_get_data (G_OBJECT (button), "tool-button-icon");
-
-  if (button->parent && GTK_IS_TOOLBAR (button->parent))
-    {
-      GtkReliefStyle relief = GTK_RELIEF_NORMAL;
-      GList *tmp;
-
-      /* set button relief to match toolbar */
-      gtk_widget_style_get (GTK_WIDGET (button->parent),
-			    "button_relief", &relief, NULL);
-      gtk_button_set_relief (GTK_BUTTON (button), relief);
-
-      /* set the button style */
-      switch (gtk_toolbar_get_style (GTK_TOOLBAR (button->parent)))
-	{
-	case GTK_TOOLBAR_ICONS:
-	  if (icon && !GTK_WIDGET_VISIBLE (icon))
-	    gtk_widget_show (icon);
-	  if (label && GTK_WIDGET_VISIBLE (label))
-	    gtk_widget_hide (label);
-	  break;
-
-	case GTK_TOOLBAR_TEXT:
-	  if (icon && GTK_WIDGET_VISIBLE (icon))
-	    gtk_widget_hide (icon);
-	  if (label && !GTK_WIDGET_VISIBLE (label))
-	    gtk_widget_show (label);
-	  break;
-
-	case GTK_TOOLBAR_BOTH:
-	  if (icon && !GTK_WIDGET_VISIBLE (icon))
-	    gtk_widget_show (icon);
-	  if (label && !GTK_WIDGET_VISIBLE (label))
-	    gtk_widget_show (label);
-
-	  if (GTK_IS_HBOX (box))
-	    {
-	      if (icon)
-		{
-		  g_object_ref (icon);
-		  gtk_container_remove (GTK_CONTAINER (box), icon);
-		}
-	      if (label)
-		{
-		  g_object_ref (label);
-		  gtk_container_remove (GTK_CONTAINER (box), label);
-		}
-	      gtk_container_remove (GTK_CONTAINER (button), box);
-	      box = gtk_vbox_new (FALSE, 0);
-
-	      gtk_widget_show (box);
-
-	      if (label)
-		{
-		  gtk_box_pack_end (GTK_BOX (box), label, FALSE, FALSE, 0);
-		  g_object_unref (label);
-		}
-	      if (icon)
-		{
-		  gtk_box_pack_end (GTK_BOX (box), icon, FALSE, FALSE, 0);
-		  g_object_unref (label);
-		}
-	      gtk_container_add (GTK_CONTAINER (button), box);
-	      g_object_set_data (G_OBJECT (button), "tool-button-box", box);
-	    }
-	  break;
-
-	case GTK_TOOLBAR_BOTH_HORIZ:
-	  if (icon && !GTK_WIDGET_VISIBLE (icon))
-	    gtk_widget_show (icon);
-	  if (label && !GTK_WIDGET_VISIBLE (label))
-	    gtk_widget_show (label);
-
-	  if (GTK_IS_VBOX (box))
-	    {
-	      if (icon)
-		{
-		  g_object_ref (icon);
-		  gtk_container_remove (GTK_CONTAINER (box), icon);
-		}
-	      if (label)
-		{
-		  g_object_ref (label);
-		  gtk_container_remove (GTK_CONTAINER (box), label);
-		}
-	      gtk_container_remove (GTK_CONTAINER (button), box);
-	      box = gtk_hbox_new (FALSE, 0);
-
-	      gtk_widget_show (box);
-
-	      if (label)
-		{
-		  gtk_box_pack_end (GTK_BOX (box), label, FALSE, FALSE, 0);
-		  g_object_unref (label);
-		}
-	      if (icon)
-		{
-		  gtk_box_pack_end (GTK_BOX (box), icon, FALSE, FALSE, 0);
-		  g_object_unref (label);
-		}
-	      gtk_container_add (GTK_CONTAINER (button), box);
-	      g_object_set_data (G_OBJECT (button), "tool-button-box", box);
-	    }
-	  break;
-	}
-
-      /* set the icon size */
-      icon = tool_button_get_icon (button);
-      if (GTK_IS_IMAGE (icon) &&
-	  gtk_image_get_storage_type (GTK_IMAGE (icon)) == GTK_IMAGE_STOCK)
-	{
-	  gchar *stock_id;
-
-	  gtk_image_get_stock (GTK_IMAGE (icon), &stock_id, NULL);
-	  stock_id = g_strdup (stock_id);
-	  gtk_image_set_from_stock (GTK_IMAGE (icon), stock_id,
-				    GTK_TOOLBAR (button->parent)->icon_size);
-	  g_free (stock_id);
-	}
-
-      /* gross hack!!! */
-      for (tmp = GTK_TOOLBAR (button->parent)->children; tmp; tmp = tmp->next)
-	{
-	  GtkToolbarChild *tool_child = tmp->data;
-
-	  if (tool_child->widget == button)
-	    {
-	      tool_child->type  = GTK_TOOLBAR_CHILD_BUTTON;
-	      tool_child->icon  = icon;
-	      tool_child->label = label;
-	      break;
-	    }
-	}
-    }
-}
-
-static GtkWidget *
-tool_button_new (GType button_type, const gchar *text, GtkWidget *icon)
-{
-  GtkWidget *button;
-  GtkWidget *vbox;
-  GtkWidget *label;
-
-  g_return_val_if_fail (g_type_is_a (button_type, GTK_TYPE_BUTTON), NULL);
-
-  button = g_object_new (button_type, NULL);
-
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (button), vbox);
-  gtk_widget_show (vbox);
-
-  label = gtk_label_new (text);
-  gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
-  gtk_box_pack_end (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-
-  if (!icon)
-    icon = gtk_image_new();
-  gtk_box_pack_end (GTK_BOX (vbox), icon, FALSE, FALSE, 0);
-
-  g_object_set_data (G_OBJECT (button), "tool-button-box", vbox);
-  g_object_set_data (G_OBJECT (button), "tool-button-label", label);
-  g_object_set_data (G_OBJECT (button), "tool-button-icon", icon);
-
-  g_signal_connect (button, "parent_set",
-		    G_CALLBACK (tool_button_parent_set), NULL);
-
-  GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);
-
-  return button;
-}
