@@ -542,10 +542,21 @@ ephy_history_window_get_type (void)
 	return ephy_history_window_type;
 }
 
+static void
+ephy_history_window_show (GtkWidget *widget)
+{
+	EphyHistoryWindow *window = EPHY_HISTORY_WINDOW (widget);
+
+	gtk_widget_grab_focus (window->priv->search_entry);
+
+	GTK_WIDGET_CLASS (parent_class)->show (widget);
+}
+
 static void
 ephy_history_window_class_init (EphyHistoryWindowClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
@@ -555,6 +566,8 @@ ephy_history_window_class_init (EphyHistoryWindowClass *klass)
 	object_class->get_property = ephy_history_window_get_property;
 	object_class->dispose  = ephy_history_window_dispose;
 
+	widget_class->show = ephy_history_window_show;
+
 	g_object_class_install_property (object_class,
 					 PROP_HISTORY,
 					 g_param_spec_object ("history",
@@ -608,17 +621,9 @@ ephy_history_window_node_activated_cb (GtkWidget *view,
 	g_return_if_fail (location != NULL);
 
 	window = EPHY_WINDOW (get_target_window (editor));
-	if (window != NULL)
-	{
-		ephy_window_load_url (EPHY_WINDOW (window), location);
-		gtk_window_present (GTK_WINDOW (window));
-	}
-	else
-	{
-		/* We have to create a browser window */
-		ephy_shell_new_tab (ephy_shell, NULL, NULL, location,
-				    EPHY_NEW_TAB_IN_NEW_WINDOW);
-	}
+	
+	ephy_shell_new_tab (ephy_shell, window, NULL, location,
+			    EPHY_NEW_TAB_OPEN_PAGE);
 }
 
 static void
@@ -644,16 +649,13 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 	if (GTK_IS_EDITABLE (focus_widget))
 	{
 		gboolean has_selection;
-		gboolean clipboard_contains_text;
 
 		has_selection = gtk_editable_get_selection_bounds
 			(GTK_EDITABLE (focus_widget), NULL, NULL);
-		clipboard_contains_text = gtk_clipboard_wait_is_text_available
-			(gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 
 		cut = has_selection;
 		copy = has_selection;
-		paste = clipboard_contains_text;
+		paste = TRUE;
 		select_all = TRUE;
 	}
 	else
