@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.99 2003/08/02 13:11:02 chpe Exp $
+ *  $Id: ephy-window.c,v 1.102.2.1 2003/09/26 16:04:26 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -51,9 +51,6 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <gtk/gtk.h>
-#include <X11/X.h>
-#include <X11/Xlib.h>
-#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include "egg-action-group.h"
 #include "egg-menu-merge.h"
@@ -687,6 +684,13 @@ setup_window (EphyWindow *window)
 	action = egg_action_group_get_action (action_group, "GoBookmarks");
 	g_object_set (action, "short_label", _("Bookmarks"), NULL);
 
+	action = egg_action_group_get_action (action_group, "EditFind");
+	g_object_set (action, "important", TRUE, NULL);
+	action = egg_action_group_get_action (action_group, "GoHome");
+	g_object_set (action, "important", TRUE, NULL);
+	action = egg_action_group_get_action (action_group, "GoBookmarks");
+	g_object_set (action, "important", TRUE, NULL);
+
 	action_group = egg_action_group_new ("PopupsActions");
 	egg_action_group_add_actions (action_group, ephy_popups_entries,
 				      ephy_popups_n_entries);
@@ -1057,6 +1061,12 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	GtkWidget *widget;
 	EphyEmbedEventType type;
 
+	/* Do not show the menu in print preview mode */
+	if (window->priv->chrome_mask & EMBED_CHROME_PPVIEWTOOLBARON)
+	{
+		return;
+	}
+
 	ephy_embed_event_get_property (event, "framed_page", &value);
 	framed = g_value_get_int (value);
 
@@ -1077,10 +1087,10 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	{
 		popup = "EphyImagePopup";
 	}
-	else if (context & EMBED_CONTEXT_INPUT)
+/*	else if (context & EMBED_CONTEXT_INPUT)
 	{
 		popup = "EphyInputPopup";
-	}
+	}*/
 	else
 	{
 		popup = framed ? "EphyFramedDocumentPopup" :
